linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH] scripts: checkversion: modernize linux/version.h search strings
@ 2021-07-27  2:57 Randy Dunlap
  2021-08-01  2:59 ` Masahiro Yamada
  0 siblings, 1 reply; 2+ messages in thread
From: Randy Dunlap @ 2021-07-27  2:57 UTC (permalink / raw)
  To: linux-kernel; +Cc: Randy Dunlap, Masahiro Yamada, Andrew Morton

Update scripts/checkversion.pl to recognize the current contents
of <linux/version.h> and both of its current locations.

Also update my email address.

Signed-off-by: Randy Dunlap <rdunlap@infradead.org>
Cc: Masahiro Yamada <masahiroy@kernel.org>
Cc: Andrew Morton <akpm@linux-foundation.org>
---
 scripts/checkversion.pl |   18 +++++++++++-------
 1 file changed, 11 insertions(+), 7 deletions(-)

--- linux-next-20210723.orig/scripts/checkversion.pl
+++ linux-next-20210723/scripts/checkversion.pl
@@ -1,10 +1,10 @@
 #! /usr/bin/env perl
 # SPDX-License-Identifier: GPL-2.0
 #
-# checkversion find uses of LINUX_VERSION_CODE or KERNEL_VERSION
-# without including <linux/version.h>, or cases of
-# including <linux/version.h> that don't need it.
-# Copyright (C) 2003, Randy Dunlap <rdunlap@xenotime.net>
+# checkversion finds uses of all macros in <linux/version.h>
+# where the source files do not #include <linux/version.h>; or cases
+# of including <linux/version.h> where it is not needed.
+# Copyright (C) 2003, Randy Dunlap <rdunlap@infradead.org>
 
 use strict;
 
@@ -13,7 +13,8 @@ $| = 1;
 my $debugging;
 
 foreach my $file (@ARGV) {
-    next if $file =~ "include/linux/version\.h";
+    next if $file =~ "include/generated/uapi/linux/version\.h";
+    next if $file =~ "usr/include/linux/version\.h";
     # Open this file.
     open( my $f, '<', $file )
       or die "Can't open $file: $!\n";
@@ -41,8 +42,11 @@ foreach my $file (@ARGV) {
 	    $iLinuxVersion      = $. if m/^\s*#\s*include\s*<linux\/version\.h>/o;
 	}
 
-	# Look for uses: LINUX_VERSION_CODE, KERNEL_VERSION, UTS_RELEASE
-	if (($_ =~ /LINUX_VERSION_CODE/) || ($_ =~ /\WKERNEL_VERSION/)) {
+	# Look for uses: LINUX_VERSION_CODE, KERNEL_VERSION,
+	# LINUX_VERSION_MAJOR, LINUX_VERSION_PATCHLEVEL, LINUX_VERSION_SUBLEVEL
+	if (($_ =~ /LINUX_VERSION_CODE/) || ($_ =~ /\WKERNEL_VERSION/) ||
+	    ($_ =~ /LINUX_VERSION_MAJOR/) || ($_ =~ /LINUX_VERSION_PATCHLEVEL/) ||
+	    ($_ =~ /LINUX_VERSION_SUBLEVEL/)) {
 	    $fUseVersion = 1;
             last if $iLinuxVersion;
         }

^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: [PATCH] scripts: checkversion: modernize linux/version.h search strings
  2021-07-27  2:57 [PATCH] scripts: checkversion: modernize linux/version.h search strings Randy Dunlap
@ 2021-08-01  2:59 ` Masahiro Yamada
  0 siblings, 0 replies; 2+ messages in thread
From: Masahiro Yamada @ 2021-08-01  2:59 UTC (permalink / raw)
  To: Randy Dunlap; +Cc: Linux Kernel Mailing List, Andrew Morton

On Tue, Jul 27, 2021 at 11:57 AM Randy Dunlap <rdunlap@infradead.org> wrote:
>
> Update scripts/checkversion.pl to recognize the current contents
> of <linux/version.h> and both of its current locations.
>
> Also update my email address.
>
> Signed-off-by: Randy Dunlap <rdunlap@infradead.org>
> Cc: Masahiro Yamada <masahiroy@kernel.org>
> Cc: Andrew Morton <akpm@linux-foundation.org>
> ---
>  scripts/checkversion.pl |   18 +++++++++++-------
>  1 file changed, 11 insertions(+), 7 deletions(-)


Applied to linux-kbuild. Thanks.


> --- linux-next-20210723.orig/scripts/checkversion.pl
> +++ linux-next-20210723/scripts/checkversion.pl
> @@ -1,10 +1,10 @@
>  #! /usr/bin/env perl
>  # SPDX-License-Identifier: GPL-2.0
>  #
> -# checkversion find uses of LINUX_VERSION_CODE or KERNEL_VERSION
> -# without including <linux/version.h>, or cases of
> -# including <linux/version.h> that don't need it.
> -# Copyright (C) 2003, Randy Dunlap <rdunlap@xenotime.net>
> +# checkversion finds uses of all macros in <linux/version.h>
> +# where the source files do not #include <linux/version.h>; or cases
> +# of including <linux/version.h> where it is not needed.
> +# Copyright (C) 2003, Randy Dunlap <rdunlap@infradead.org>
>
>  use strict;
>
> @@ -13,7 +13,8 @@ $| = 1;
>  my $debugging;
>
>  foreach my $file (@ARGV) {
> -    next if $file =~ "include/linux/version\.h";
> +    next if $file =~ "include/generated/uapi/linux/version\.h";
> +    next if $file =~ "usr/include/linux/version\.h";
>      # Open this file.
>      open( my $f, '<', $file )
>        or die "Can't open $file: $!\n";
> @@ -41,8 +42,11 @@ foreach my $file (@ARGV) {
>             $iLinuxVersion      = $. if m/^\s*#\s*include\s*<linux\/version\.h>/o;
>         }
>
> -       # Look for uses: LINUX_VERSION_CODE, KERNEL_VERSION, UTS_RELEASE
> -       if (($_ =~ /LINUX_VERSION_CODE/) || ($_ =~ /\WKERNEL_VERSION/)) {
> +       # Look for uses: LINUX_VERSION_CODE, KERNEL_VERSION,
> +       # LINUX_VERSION_MAJOR, LINUX_VERSION_PATCHLEVEL, LINUX_VERSION_SUBLEVEL
> +       if (($_ =~ /LINUX_VERSION_CODE/) || ($_ =~ /\WKERNEL_VERSION/) ||
> +           ($_ =~ /LINUX_VERSION_MAJOR/) || ($_ =~ /LINUX_VERSION_PATCHLEVEL/) ||
> +           ($_ =~ /LINUX_VERSION_SUBLEVEL/)) {
>             $fUseVersion = 1;
>              last if $iLinuxVersion;
>          }



-- 
Best Regards
Masahiro Yamada

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2021-08-01  3:00 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2021-07-27  2:57 [PATCH] scripts: checkversion: modernize linux/version.h search strings Randy Dunlap
2021-08-01  2:59 ` Masahiro Yamada

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).